==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/Effect/bs2b/translations/bs2b_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr">
<context>
    <name>EffectBs2bFactory</name>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="32"/>
        <source>BS2B Plugin</source>
        <translation>BS2B Eklentisi</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="52"/>
        <source>About BS2B Effect Plugin</source>
        <translation>BS2B Efekt Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="53"/>
        <source>This is the Qmmp plugin version of Boris Mikhaylov&apos;s headphone DSP effect &quot;Bauer stereophonic-to-binaural&quot;, abbreviated bs2b.</source>
        <translation>Bu eklenti Boris Mikhaylov&apos;un &quot;Bauer-stereophonic-to-binaural&quot;, kısaca bs2b, kulaklık DSP efektinin Qmmp sürümüdür.</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="55"/>
        <source>Visit %1 for more details</source>
        <translation>Detaylar için %1 adresini ziyaret edin</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="57"/>
        <source>Compiled against libbs2b-%1</source>
        <translation>libbs2b-%1 ile derlenmiştir</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="58"/>
        <source>Developers:</source>
        <translation>Geliştiriciler:</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="59"/>
        <source>Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="60"/>
        <source>Sebastian Pipping &amp;lt;sebastian@pipping.org&amp;gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>BS2B Plugin Settings</source>
        <translation>BS2B Eklenti Ayarları</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="32"/>
        <source>Crossfeed level</source>
        <translation>Crossfeed seviyesi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <location filename="../settingsdialog.ui" line="59"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Default</source>
        <translation>Öntanımlı</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>C.Moy</source>
        <translation>C.Moy</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="85"/>
        <source>J. Meier</source>
        <translation>J. Meier</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="60"/>
        <source>%1 Hz, %2 us</source>
        <translation>%1 Hz, %2 us</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="67"/>
        <source>%1 dB</source>
        <translation>%1 dB</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Effect/bs2b/translations/bs2b_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr_TR">
<context>
    <name>EffectBs2bFactory</name>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="32"/>
        <source>BS2B Plugin</source>
        <translation>BS2B Eklentisi</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="52"/>
        <source>About BS2B Effect Plugin</source>
        <translation>BS2B Efekt Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="53"/>
        <source>This is the Qmmp plugin version of Boris Mikhaylov&apos;s headphone DSP effect &quot;Bauer stereophonic-to-binaural&quot;, abbreviated bs2b.</source>
        <translation>Bu eklenti Boris Mikhaylov&apos;un &quot;Bauer-stereophonic-to-binaural&quot;, kısaca bs2b, kulaklık DSP efektinin Qmmp sürümüdür.</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="55"/>
        <source>Visit %1 for more details</source>
        <translation>Detaylar için %1 adresini ziyaret edin</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="57"/>
        <source>Compiled against libbs2b-%1</source>
        <translation>libbs2b-%1 ile derlenmiştir</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="58"/>
        <source>Developers:</source>
        <translation>Geliştiriciler:</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="59"/>
        <source>Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="60"/>
        <source>Sebastian Pipping &lt;sebastian@pipping.org&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="60"/>
        <source>%1 Hz, %2 us</source>
        <translation>%1 Hz, %2 us</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="67"/>
        <source>%1 dB</source>
        <translation>%1 dB</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>BS2B Plugin Settings</source>
        <translation>BS2B Eklenti Ayarları</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="32"/>
        <source>Crossfeed level</source>
        <translation>Crossfeed seviyesi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <location filename="../settingsdialog.ui" line="59"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Default</source>
        <translation>Öntanımlı</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>C.Moy</source>
        <translation>C.Moy</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="85"/>
        <source>J. Meier</source>
        <translation>J. Meier</translation>
    </message>
</context>
</TS>
